@@ -8,23 +8,20 @@ class AddDataToCoTList:
     def send(self, pipes, data):
         for pipe in pipes:
             try:
-
-                #print('putting data in pipe')
-                pipe.put(data)
+                pipe.send(data)
             except Exception as e:
                 print(e)
                 pass
         return 1
 
     #this function attempts to receive data from a specified pipe and then return the data
-
-    def recv(self, pipe, timeout = None):
+    def recv(self, pipe):
         try:
-            if not pipe.empty():
-                data = pipe.get(timeout = timeout)
+            out = pipe.poll(timeout=0.1)
+            if out:
+                data = pipe.recv()
                 return data
             else:
                 return 0
         except Exception as e:
-
-            print(e)
+            print(e)
\ No newline at end of file
